Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(699)

Unified Diff: chrome/browser/extensions/app_sync_bundle.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/app_sync_bundle.h
diff --git a/chrome/browser/extensions/app_sync_bundle.h b/chrome/browser/extensions/app_sync_bundle.h
index d3d444df254bad029b57396c7747e38ab30857d9..70881395018f6ffb040bb053b5ef5c36668a1ec6 100644
--- a/chrome/browser/extensions/app_sync_bundle.h
+++ b/chrome/browser/extensions/app_sync_bundle.h
@@ -16,10 +16,13 @@
#include "chrome/browser/extensions/app_sync_data.h"
#include "sync/api/syncable_service.h"
-class SyncChangeProcessor;
class ExtensionService;
class ExtensionSet;
+
+namespace csync {
+class SyncChangeProcessor;
class SyncErrorFactory;
+}
namespace extensions {
@@ -32,25 +35,26 @@ class AppSyncBundle {
virtual ~AppSyncBundle();
// Setup this bundle to be sync application data.
- void SetupSync(SyncChangeProcessor* sync_proccessor,
- SyncErrorFactory* sync_error_factory,
- const SyncDataList& initial_sync_data);
+ void SetupSync(csync::SyncChangeProcessor* sync_proccessor,
+ csync::SyncErrorFactory* sync_error_factory,
+ const csync::SyncDataList& initial_sync_data);
// Resets this class back to it default values, which will disable all syncing
// until a new sync processor is set.
void Reset();
- // Returns a SyncChange that will delete the given application.
- SyncChange CreateSyncChangeToDelete(const Extension* extension) const;
+ // Returns a csync::SyncChange that will delete the given application.
+ csync::SyncChange CreateSyncChangeToDelete(const Extension* extension) const;
// Process the sync deletion of the given application.
- void ProcessDeletion(std::string extension_id, const SyncChange& sync_change);
+ void ProcessDeletion(
+ std::string extension_id, const csync::SyncChange& sync_change);
// Create a sync change based on |sync_data|.
- SyncChange CreateSyncChange(const SyncData& sync_data);
+ csync::SyncChange CreateSyncChange(const csync::SyncData& sync_data);
// Get all the sync data contained in this bundle.
- SyncDataList GetAllSyncData() const;
+ csync::SyncDataList GetAllSyncData() const;
// Sync a newly-installed application or change an existing one.
void SyncChangeIfNeeded(const Extension& extension);
@@ -59,7 +63,7 @@ class AppSyncBundle {
void ProcessSyncChange(AppSyncData app_sync_data);
// Process the list of sync changes.
- void ProcessSyncChangeList(SyncChangeList sync_change_list);
+ void ProcessSyncChangeList(csync::SyncChangeList sync_change_list);
// Check to see if the given |id| is either synced or pending to be synced.
bool HasExtensionId(const std::string& id) const;
@@ -91,8 +95,8 @@ class AppSyncBundle {
void MarkPendingAppSynced(const std::string& id);
ExtensionService* extension_service_; // Own us.
- scoped_ptr<SyncChangeProcessor> sync_processor_;
- scoped_ptr<SyncErrorFactory> sync_error_factory_;
+ scoped_ptr<csync::SyncChangeProcessor> sync_processor_;
+ scoped_ptr<csync::SyncErrorFactory> sync_error_factory_;
std::set<std::string> synced_apps_;
std::map<std::string, AppSyncData> pending_sync_data_;
« no previous file with comments | « chrome/browser/extensions/app_notification_manager_sync_unittest.cc ('k') | chrome/browser/extensions/app_sync_bundle.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698